"use strict";
const log = require("fary-log");
const Koa = require("koa");
const koaCompress = require("koa-compress");
const koaLogger = require("koa-logger");
const errorMiddleware = require("./middlewares/error");
const proxyMiddleware = require("./middlewares/proxy");
const checkProxy = require("./utils/check-proxy");
const ENV = require("./utils/env");
const serverConfig = require("./utils/server-config");
const { IS_DEV } = ENV;
const logger = log('fary:app');
/**
 * createApp
 * @param {Object} options - options
 * @param {Function} onStart - callback after server start
 * @return {Koa} app - serverApp
 */
// tslint:disable-next-line:no-empty
function createApp({ port = serverConfig.value.port, middlewares = [], skipListen = false, proxy = serverConfig.value.proxy, preProxy, postProxy, } = {}, onStart = () => { }) {
    checkProxy(proxy);
    logger.log(`Debug mode:`, IS_DEV);
    logger.log(`Proxy mapping:`, proxy);
    const app = new Koa();
    // trust proxy
    app.proxy = true;
    const allMiddlewares = [
        // request/response log
        koaLogger(),
        // compress the response
        koaCompress(),
        // error handler
        errorMiddleware(),
        ...middlewares,
        // proxy handler
        proxyMiddleware({
            postProxy,
            preProxy,
        }),
    ];
    allMiddlewares.forEach((middleware) => {
        if (!middleware) {
            return;
        }
        app.use(middleware);
    });
    app.on('error', (err) => {
        logger.error(`Server error: \n ${err.stack}`);
    });
    if (!skipListen) {
        app.listen(port, () => {
            logger.info(`Koa server is listening at ${port}`);
            onStart();
        });
    }
    process.on('SIGINT', () => {
        process.exit();
    });
    process.on('unhandledRejection', (err) => {
        throw err;
    });
    return app;
}
module.exports = createApp;
//# sourceMappingURL=index.js.map