export declare type IProxyTargets = string | string[];
/**
 * Load balance for proxy
 * Currently use random algorithm.
 * At the beginning, considering all the targets are healthy.
 * Check every proxy target if they are healthy intervarlly.
 * If all the targets are not healthy, it will throw error when method `pick` is invoked.
 */
declare class ProxyLoadBalancer {
    totalTargets: string[];
    healthyTargets: string[];
    private options;
    /**
     * constructor
     * @param {IProxyTargets} targets - proxy targets
     * @param {IProxyLoadBalancerOptions} options - options
     */
    constructor(targets: IProxyTargets, {enableHealthCheck, healthCheckPath, healthCheckTimeout, healthCheckInterval}?: {
        enableHealthCheck?: boolean;
        healthCheckPath?: string;
        healthCheckTimeout?: number;
        healthCheckInterval?: number;
    });
    /**
     * setup health check interval timer
     */
    startIntervalCheck(): void;
    /**
     * the main process of health check
     */
    checkHealth(): Promise<void>;
    /**
     * pick a healthy target randomly
     * if `enableHealthCheck` is `false`, this can not guarantee the returned target is healthy
     * @return {string} proxy target
     */
    pick(): string;
}
export default ProxyLoadBalancer;
